Skip to contents

Constructor function for an interface for use with R6.class

Usage

R6.interface(
  interfacename = NULL,
  public = list(),
  private = list(),
  active = list()
)

Arguments

interfacename

Name of the interface. The interface name is useful primarily for S3 method dispatch.

public

A list of public members, which can be functions (methods) and non-functions (fields).

private

An optional list of private members, which can be functions and non-functions.

active

An optional list of active binding functions.

Value

Object of class R6.interface