Skip to contents

Constructor function for an object of class [distribution.discrete.finite_set.class]

Usage

distribution.finite_set(prob, support)

Arguments

prob

vector of probability weights for obtaining each element of support.

support

vector of values giving the points in the finite set on which the distribution has support.

Value

An object of class [distribution.discrete.finite_set.class]