logistic(x) = 1 / (1 + exp(-x)), a wrapper for stats::plogis()
Arguments
- ...
A numeric vector of values, and other named arguments to
stats::plogis()if desired.
logistic(x) = 1 / (1 + exp(-x)), a wrapper for stats::plogis()
A numeric vector of values, and other named arguments to stats::plogis() if desired.