Skip to contents

Example data from Stan analysis of simple linear normal regression

Usage

stan_example_regression

Format

stan_example_regression

A list with three elements:

posterior_samples

A stanfit object containing samples from the posterior

prior_samples

A stanfit object containing samples from the posterior

true_values

A named character vector with the true parameter values

...