Constructor function for an interface for use with R6.class
Arguments
- interfacename
Name of the interface. The interface name is useful primarily for S3 method dispatch.
- public
A list of public members, which can be functions (methods) and non-functions (fields).
- private
An optional list of private members, which can be functions and non-functions.
- active
An optional list of active binding functions.