Base class for univariate discrete distributions
Super classes
mastiff::R6.class.class -> mastiff::distribution.abstract.class -> distribution.discrete.class
Active bindings
interfacesThe list of available class interfaces.
supportThe support of the continuous distribution, i.e. the subset of values for which the density is positive,
Methods
Method new()
Create a new object of class distribution.discrete.class
Usage
distribution.discrete.class$new(support = c(0, Inf))Method p()
Evaluates the distribution function of a discrete random
variable with finite integer support given density function $d()
Method q()
Evaluates the distribution function of a discrete random
variable with finite integer support given distribution function $p()